@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Data::Dumper;
 use HTML::Entities;
@@ -13,36 +13,16 @@ sub new {
     return bless { %attrs }, $class;
 }
 
-sub generate {
+sub generate { _make_table( _data( @_ ) ) }
+
+sub transpose { _make_table( @{ Math::Matrix::transpose( [ _data( @_ ) ] ) } ) }
+
+sub reverse { _make_table( reverse _data( @_ ) ) }
+
+sub process_data {
     my ($self, @data);
 
-    if (ref($_[0]) eq __PACKAGE__) {
-        $self = shift;
-        @data = $self->get_data;
-    } else {
-        @data = get_data( @_ );
-    }
-
-    return _make_table( @data );
-}
-
-sub transpose {
-    my ($self, @data);
-
-    if (ref($_[0]) eq __PACKAGE__) {
-        $self = shift;
-        @data = $self->get_data;
-    } else {
-        @data = get_data( @_ );
-    }
-
-    return _make_table( @{ Math::Matrix::transpose(\@data) } );
-}
-
-sub get_data {
-    my ($self, @data);
-
-    if (ref($_[0]) eq __PACKAGE__) {
+    if (ref($_[0]) =~ /(?:Spreadsheet|DBIx)::HTML/) {
         # called as method
         $self = shift;
         return @{ $self->{data} } if $self->{__processed_data__};
@@ -60,6 +40,17 @@ sub get_data {
     return @{ $self->{data} };
 }
 
+sub _data {
+    my ($self, @data);
+    if (ref($_[0]) eq __PACKAGE__) {
+        $self = shift;
+        @data = $self->process_data;
+    } else {
+        @data = process_data( @_ );
+    }
+    return @data;
+}
+
 sub _make_table {
     my $rows = '';
     for my $row (@_) {
@@ -113,6 +104,20 @@ __END__
 
 Spreadsheet::HTML - Tabular data to HTML tables.
 
+=head1 REQUIRES
+
+=over 4
+
+=item HTML::Entities
+
+Used to encode values with HTML entities.
+
+=item Math::Matrix
+
+Used to transpose data from portrait to landscape.
+
+=back
+
 =head1 SYNOPSIS
 
     use Spreadsheet::HTML;
@@ -127,9 +132,11 @@ Spreadsheet::HTML - Tabular data to HTML tables.
     my $table = Spreadsheet::HTML->new( data => $data );
     print $table->generate;
     print $table->transpose;
+    print $table->reverse;
 
     print Spreadsheet::HTML::generate( $data );
     print Spreadsheet::HTML::transpose( $data );
+    print Spreadsheet::HTML::reverse( $data );
 
 =head1 METHODS
 
@@ -146,16 +153,39 @@ of <td> tags).
 =item generate()
 
 Returns a string that contains the rendered HTML table.
+Currently (and subject to change if better ideas arise),
+all data will:
+
+=over 8
+
+=item - be converted to &nbsp; if empty
+
+=item - be HTML entity decoded
+
+=item - be HTML entity encoded
+
+=item - have any newlines converted to <br> tags
+
+=back
+
+The first row of the data will have columns wrapped with
+<tr> tags and the remaining rows will be wraped with 
+<td> tags.
 
 =item transpose()
 
-Uses Math::Matrix to transpose the data and then returns
-a string containing the rendered HTML table.
+Uses Math::Matrix to rotate the data 90 degrees and
+then returns a string containing the rendered HTML table.
 
-=item get_data()
+=item reverse()
 
-Should be an internal private method, but returns the 
-munged data before it is used to generate the HTML table.
+Uses Math::Matrix to rotate the data 180 degrees and
+then returns a string containing the rendered HTML table.
+
+=item process_data()
+
+Returns the munged data before it is used to generate
+a rendered HTML table.
 
 =back
 
@@ -165,8 +195,20 @@ Jeff Anderson, C<< <jeffa at cpan.org> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-spreadsheet-html at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Spreadsheet-HTML>.
+Please report any bugs or feature requests to either
+
+=over 4
+
+=item * C<bug-spreadsheet-html at rt.cpan.org>
+
+  Send an email.
+
+=item * L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Spreadsheet-HTML>.
+
+  Use the web interface.
+
+=back
+
 I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
@@ -175,6 +217,8 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Spreadsheet::HTML
 
+The Github project is L<https://github.com/jeffa/Spreadsheet-HTML>
+
 You can also look for information at:
 
 =over 4
